Crate kurage

Crate kurage 

🪼

To get started with 🪼, see:

Remember to invoke kurage_gen_macros! in your crate!

For actual real-world examples of 🪼, take a look at:

Modules

paste
github crates-io docs-rs
relm4
An idiomatic GUI library inspired by Elm and based on gtk4-rs.
shortcuts
tracing
A scoped, structured logging and diagnostics system.

Macros

gen_shortcut
generate_component
Generate a relm4::SimpleComponent.
generate_generator
Generate a macro_rules! that has a similar syntax to [kurage::generate_component!], except that the new macro generates components wrapped in a custom tree of widgets.
generate_pages
kurage_gen_macros
Macros used by other 🪼 macros.

Attribute Macros

mangle_ident
Panics